@@ -67,7 +67,7 @@ def AGS4_to_dict(filepath_or_buffer, encoding='utf-8', get_line_numbers=False, r
     if _is_file_like(filepath_or_buffer):
         f = filepath_or_buffer
         f.seek(0)
-        if hasattr(f, 'encoding') and getattr(f, 'encoding', None) != encoding:
+        if hasattr(f, 'encoding') and getattr(f, 'encoding', None) != encoding and hasattr(f, 'reconfigure'):
             f.reconfigure(encoding=encoding)
         close_file = False
     else:
@@ -715,8 +715,8 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
         Dictionary contains AGS4 error in input file.
     """
 
+    import hashlib
     from python_ags4 import check
-    import traceback
 
     ags_errors = {}
 
@@ -726,7 +726,7 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
     if _is_file_like(filepath_or_buffer):
         f = filepath_or_buffer
         f.seek(0)
-        if hasattr(f, 'encoding') and getattr(f, 'encoding', None) != encoding:
+        if hasattr(f, 'encoding') and getattr(f, 'encoding', None) != encoding and hasattr(f, 'reconfigure'):
             f.reconfigure(encoding=encoding)
         close_file = False
     else:
@@ -734,15 +734,21 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
         close_file = True
 
     try:
-        # Preflight check for AGS3 files
+        # Preflight check for AGS3 files and to calculate SHA256 hash of file
+        sha256_hash = hashlib.sha256()
+
         for i, line in enumerate(f, start=1):
             ags_errors = check.is_ags3_like(line, i, ags_errors=ags_errors)
 
             # Exit if ags3_like line is found
             if ('AGS Format Rule 3' in ags_errors) and ('AGS3' in ags_errors['AGS Format Rule 3'][0]['desc']):
-                ags_errors = check.add_meta_data(filepath_or_buffer, standard_AGS4_dictionary, ags_errors=ags_errors, encoding=encoding)
+                ags_errors = check.add_error_msg(ags_errors, 'Validator Process Error', '-', '',
+                                                 'Validation terminated due to suspected AGS3 file. Please fix errors and try again.')
                 return ags_errors
 
+            # Perform SHA256 checksum calculation
+            sha256_hash.update(line.encode(encoding))
+
         # Reset file stream to the beginning to start AGS4 checks
         f.seek(0)
 
@@ -786,7 +792,6 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
             ags_errors = check.rule_19a(line, i, group=group, ags_errors=ags_errors)
             ags_errors = check.rule_19b_1(line, i, group=group, ags_errors=ags_errors)
 
-
         # Add additional information about how Rule 1 is implemented if infringements are detected
         if 'AGS Format Rule 1' in ags_errors:
             msg = "AGS4 Rule 1 is interpreted as allowing both standard ASCII characters (Unicode code points 0-127) "\
@@ -854,7 +859,10 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
         ags_errors = check.rule_19b_3(tables, headings, dictionary, line_numbers, ags_errors=ags_errors)
 
         # Warnings
-        ags_errors = check.warning_16_1(tables, headings, tables_std_dict['ABBR'], ags_errors=ags_errors)
+        # TO BE ADDED
+
+        # FYI
+        ags_errors = check.fyi_16_1(tables, headings, tables_std_dict['ABBR'], ags_errors=ags_errors)
 
         # Add summary of data
         for val in check.get_data_summary(tables):
@@ -899,6 +907,15 @@ def check_file(filepath_or_buffer, standard_AGS4_dictionary=None, rename_duplica
         # Add metadata
         ags_errors = check.add_meta_data(filepath_or_buffer, standard_AGS4_dictionary, ags_errors=ags_errors,
                                          encoding=encoding)
+
+        if ('AGS Format Rule 3' in ags_errors) and ('AGS3' in ags_errors['AGS Format Rule 3'][0]['desc']):
+            # If AGS3 file is detected, the for loop in which the SHA256 hash is
+            # calculated will be terminated, therefore report it as "Not calculated"
+            ags_errors = check.add_error_msg(ags_errors, 'Metadata', 'SHA256 hash', '', 'Not calculated')
+
+        else:
+            ags_errors = check.add_error_msg(ags_errors, 'Metadata', 'SHA256 hash', '', sha256_hash.hexdigest())
+
         return ags_errors
 
 
